@@ -20,10 +20,6 @@ class GameMode(EnumModel):
     TAIKO = "taiko"
     CATCH = "fruits"
     MANIA = "mania"
-    # deprecated, remove in 3.x.x
-    CTB   = "fruits"
-    # deprecated, remove in 3.x.x
-    STD   = "osu"
 
 class PlayStyles(IntFlagModel):
     MOUSE = 1
@@ -171,9 +167,7 @@ class EventType(EnumModel):
     USER_SUPPORT_GIFT = "userSupportGift"
     USERNAME_CHANGE = "usernameChange"
 
-# TODO this is just a subset of `RankStatus`, and is only (currently) used for
-# `EventType.BEATMAPSET_APPROVE`. Find some way to de-duplicate? Could move to
-# `RankStatus`, but then how to enforce taking on only a subset of values?
+# used for `EventType.BEATMAPSET_APPROVE`
 class BeatmapsetApproval(EnumModel):
     RANKED = "ranked"
     APPROVED = "approved"
@@ -185,6 +179,9 @@ class ForumTopicType(EnumModel):
     STICKY = "sticky"
     ANNOUNCEMENT = "announcement"
 
+class ChangelogMessageFormat(EnumModel):
+    HTML = "html"
+    MARKDOWN = "markdown"
 
 # ==================
 # Undocumented Enums
@@ -192,7 +189,8 @@ class ForumTopicType(EnumModel):
 
 class UserRelationType(EnumModel):
     # undocumented
-    # https://github.com/ppy/osu-web/blob/master/app/Transformers/UserRelationTransformer.php#L20
+    # https://github.com/ppy/osu-web/blob/master/app/Transformers/
+    # UserRelationTransformer.php#L20
     FRIEND = "friend"
     BLOCK = "block"
 
@@ -207,6 +205,48 @@ class Grade(EnumModel):
     D = "D"
     F = "F"
 
+class RoomType(EnumModel):
+    # https://github.com/ppy/osu-web/blob/3d1586392102b05f2a3b264905c4dbb7b2d43
+    # 0a2/resources/js/interfaces/room-json.ts#L10
+    PLAYLISTS = "playlists"
+    HEAD_TO_HEAD = "head_to_head"
+    TEAM_VERSUS = "team_versus"
+
+class RoomCategory(EnumModel):
+    # https://github.com/ppy/osu-web/blob/3d1586392102b05f2a3b264905c4dbb7b2d
+    # 430a2/resources/js/interfaces/room-json.ts#L7
+    NORMAL = "normal"
+    SPOTLIGHT = "spotlight"
+
+class MatchEventType(EnumModel):
+    # https://github.dev/ppy/osu-web/blob/3d1586392102b05f2a3b264905c4dbb7b2
+    # d430a2/app/Models/LegacyMatch/Event.php#L30
+    PLAYER_LEFT = "player-left"
+    PLAYER_JOINED = "player-joined"
+    PLAYER_KICKED = "player-kicked"
+    MATCH_CREATED = "match-created"
+    MATCH_DISBANDED = "match-disbanded"
+    HOST_CHANGED = "host-changed"
+    OTHER = "other"
+
+
+class ScoringType(EnumModel):
+    # https://github.com/ppy/osu-web/blob/3d1586392102b05f2a3b264905c4dbb7b2d4
+    # 30a2/app/Models/LegacyMatch/Game.php#L40
+    SCORE = "score"
+    ACCURACY = "accuracy"
+    COMBO = "combo"
+    SCORE_V2 = "scorev2"
+
+class TeamType(EnumModel):
+    # https://github.com/ppy/osu-web/blob/3d1586392102b05f2a3b264905c4dbb7b2d43
+    # 0a2/app/Models/LegacyMatch/Game.php#L47
+    HEAD_TO_HEAD = "head-to-head"
+    TAG_COOP = "tag-coop"
+    TEAM_VS = "team-vs"
+    TAG_TEAM_VS = "tag-team-vs"
+
+
 
 # ===============
 # Parameter Enums
@@ -377,6 +417,16 @@ class NewsPostKey(EnumModel):
     SLUG = "slug"
     ID = "id"
 
+# `RoomType` is already taken as a model name (and more appropriate elsewhere)
+class RoomSearchType(EnumModel):
+    # https://github.com/ppy/osu-web/blob/3d1586392102b05f2a3b264905c4dbb7b2d4
+    # 30a2/routes/web.php#L462
+    OWNED = "owned"
+    PARTICIPATED = "participated"
+    ENDED = "ended"
+
+
+
 # =================
 # Documented Models
 # =================
@@ -494,8 +544,7 @@ class KudosuGiver(Model):
 
 class KudosuPost(Model):
     url: Optional[str]
-    # will be "[deleted beatmap]" for deleted beatmaps. TODO codify this
-    # somehow? another enum perhaps? see
+    # will be "[deleted beatmap]" for deleted beatmaps. See
     # https://osu.ppy.sh/docs/index.html#kudosuhistory
     title: str
 
